@@ -15,12 +15,13 @@ def mnist_dataset_fn(seed: int, **config) -> Dict:
     """
     np.random.seed(seed)
 
-    transform = transforms.Compose(
-        [
-            transforms.ToTensor(),
-            transforms.Normalize((0.1307,), (0.3081,)),  # (mean,std) of MNIST train set
-        ]
-    )
+    transform_list = [
+        transforms.ToTensor(),
+        transforms.Normalize((0.1307,), (0.3081,)),  # (mean,std) of MNIST train set
+    ]
+    if config.get("apply_augmentation"):
+        transform_list = [transforms.RandomHorizontalFlip()] + transform_list
+    transform = transforms.Compose(transform_list)
     train_dataset = datasets.MNIST("../data", train=True, download=True, transform=transform)
     validation_dataset = datasets.MNIST(
         "../data", train=False, download=True, transform=transform
@@ -28,7 +29,7 @@ def mnist_dataset_fn(seed: int, **config) -> Dict:
     test_dataset = datasets.MNIST("../data", train=False, download=True, transform=transform)
     batch_size = config.get("batch_size", 64)
     return {
-        "train": DataLoader(train_dataset, batch_size=batch_size),
+        "train": DataLoader(train_dataset, batch_size=batch_size, shuffle=config.get("shuffle", True)),
         "validation": DataLoader(validation_dataset, batch_size=batch_size),
         "test": DataLoader(test_dataset, batch_size=batch_size),
     }
